==> xlniuxdata-vipgame-1.0.65-20170103.065824-54-sources.jar: com/xunlei/niux/data/vipgame/vo/customerService/CsCallerDemand.java <==
package com.xunlei.niux.data.vipgame.vo.customerService;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * Created by zhangya on 2016/12/20.
 */
@Table(tableName = "cs_caller_demand", pkFieldName = "seqid", pkFieldAssign = false)
public class CsCallerDemand {

    private Long seqid;
    private String demandName;
    private String gameId;
    private String type;
    private String backflow;
    private String rule;
    private String beginTime;
    private String endTime;
    private Integer total;
    private String remark;
    private String inputTime;
    private String inputBy;
    private String editBy;
    private String editTime;
    private Integer status;

    @Column(columnName="beginTime",isWhereColumn=true,operator= Operator.GE)
    private String fromBeginTime;
    @Column(columnName="beginTime",isWhereColumn=true,operator= Operator.LE)
    private String toBeginTime;
    @Column(columnName="demandName",isWhereColumn=true,operator= Operator.LIKE)
    private String demandLIke;

    public String getDemandLIke() {
        return demandLIke;
    }

    public void setDemandLIke(String demandLIke) {
        this.demandLIke = demandLIke;
    }

    public String getToBeginTime() {
        return toBeginTime;
    }

    public void setToBeginTime(String toBeginTime) {
        this.toBeginTime = toBeginTime;
    }

    public String getFromBeginTime() {
        return fromBeginTime;
    }

    public void setFromBeginTime(String fromBeginTime) {
        this.fromBeginTime = fromBeginTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getDemandName() {
        return demandName;
    }

    public void setDemandName(String demandName) {
        this.demandName = demandName;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getBackflow() {
        return backflow;
    }

    public void setBackflow(String backflow) {
        this.backflow = backflow;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}

==> xlniuxdata-vipgame-1.0.65-20170502.025519-76-sources.jar: com/xunlei/niux/data/vipgame/vo/customerService/CsCallerDemand.java <==
package com.xunlei.niux.data.vipgame.vo.customerService;

import com.ferret.common.dao.annotation.Column;
import com.ferret.common.dao.annotation.Table;
import com.ferret.common.dao.enums.Operator;

/**
 * Created by zhangya on 2016/12/20.
 */
@Table(tableName = "cs_caller_demand", pkFieldName = "seqid", pkFieldAssign = false)
public class CsCallerDemand {

    private Long seqid;
    private String demandName;
    private String gameId;
    private String type;
    private String backflow;
    private String rule;
    private String beginTime;
    private String endTime;
    private Integer total;
    private String remark;
    private String inputTime;
    private String inputBy;
    private String editBy;
    private String editTime;
    private Integer status;

    @Column(columnName="beginTime",isWhereColumn=true,operator= Operator.GE)
    private String fromBeginTime;
    @Column(columnName="beginTime",isWhereColumn=true,operator= Operator.LE)
    private String toBeginTime;
    @Column(columnName="demandName",isWhereColumn=true,operator= Operator.LIKE)
    private String demandLIke;

    private String giftId;

    public String getGiftId() {
        return giftId;
    }

    public void setGiftId(String giftId) {
        this.giftId = giftId;
    }

    public String getDemandLIke() {
        return demandLIke;
    }

    public void setDemandLIke(String demandLIke) {
        this.demandLIke = demandLIke;
    }

    public String getToBeginTime() {
        return toBeginTime;
    }

    public void setToBeginTime(String toBeginTime) {
        this.toBeginTime = toBeginTime;
    }

    public String getFromBeginTime() {
        return fromBeginTime;
    }

    public void setFromBeginTime(String fromBeginTime) {
        this.fromBeginTime = fromBeginTime;
    }

    public Long getSeqid() {
        return seqid;
    }

    public void setSeqid(Long seqid) {
        this.seqid = seqid;
    }

    public String getDemandName() {
        return demandName;
    }

    public void setDemandName(String demandName) {
        this.demandName = demandName;
    }

    public String getGameId() {
        return gameId;
    }

    public void setGameId(String gameId) {
        this.gameId = gameId;
    }

    public String getType() {
        return type;
    }

    public void setType(String type) {
        this.type = type;
    }

    public String getBackflow() {
        return backflow;
    }

    public void setBackflow(String backflow) {
        this.backflow = backflow;
    }

    public String getRule() {
        return rule;
    }

    public void setRule(String rule) {
        this.rule = rule;
    }

    public String getBeginTime() {
        return beginTime;
    }

    public void setBeginTime(String beginTime) {
        this.beginTime = beginTime;
    }

    public String getEndTime() {
        return endTime;
    }

    public void setEndTime(String endTime) {
        this.endTime = endTime;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public String getInputTime() {
        return inputTime;
    }

    public void setInputTime(String inputTime) {
        this.inputTime = inputTime;
    }

    public String getInputBy() {
        return inputBy;
    }

    public void setInputBy(String inputBy) {
        this.inputBy = inputBy;
    }

    public String getEditBy() {
        return editBy;
    }

    public void setEditBy(String editBy) {
        this.editBy = editBy;
    }

    public String getEditTime() {
        return editTime;
    }

    public void setEditTime(String editTime) {
        this.editTime = editTime;
    }

    public Integer getStatus() {
        return status;
    }

    public void setStatus(Integer status) {
        this.status = status;
    }
}
